# soma-base                                                                                                                       [![](https://travis-ci.org/populse/soma-base.svg?branch=master)](https://travis-ci.org/populse/soma-base) [![](https://ci.appveyor.com/api/projects/status/ddfnffj4kq2msi1u?svg=true)](https://ci.appveyor.com/project/denisri/soma-base/branch/master) [![](https://codecov.io/github/populse/soma-base/coverage.svg?branch=master)](https://codecov.io/github/populse/soma-base) [![](https://img.shields.io/badge/license-CeCILL--B-blue.svg)](https://github.com/populse/soma-base/blob/master/LICENSE.en) [![](https://img.shields.io/pypi/v/soma-base.svg)](https://pypi.python.org/pypi/soma-base/)                                           [![](https://img.shields.io/badge/python-2.7%2C%203.3%2C%203.4%2C%203.5%2C%203.6%2C%203.7-yellow.svg)](#)                                                                      [![](https://img.shields.io/badge/platform-Linux%2C%20OSX%2C%20Windows-orange.svg)](#)

Miscellaneous libs for the python environment of Populse / BrainVISA

# Documentation

* Docs of the git master branch: https://populse.github.io/soma-base/
* Docs of the released versions are on http://brainvisa.info/soma-base/sphinx/index.html

# Download

* [On Pypi](https://pypi.org/project/soma-base/) for `pip install soma-base`
* [BrainVISA packages download:](http://brainvisa.info/web/download.html)
